@@ -2,7 +2,7 @@
  * GChemUtils GOffice component
  * gchemutils.cc
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -22,12 +22,16 @@
 
 #include "config.h"
 #include "gchemutils-priv.h"
+#include "gogcpapp.h"
 
 #include <gsf/gsf-impl-utils.h>
 #include <goffice/app/module-plugin-defs.h>
 #include <goffice/component/go-component-factory.h>
 #include <openbabel/mol.h>
 #include <libintl.h>
+#include <map>
+#include <string>
+#include <cstring>
 
 //gcuGOfficeApplication *app;
 
@@ -42,39 +46,65 @@ extern GOPluginModuleHeader const go_plugin_header =
 
 static GObjectClass *gogcu_parent_klass;
 
+using namespace std;
+static map <string, GOGcuApplication *> Apps;
+
 static gboolean
 go_gchemutils_component_get_data (GOComponent *component, gpointer *data, int *length,
 									void (**clearfunc) (gpointer), gpointer *user_data)
 {
 	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (component);
-	bool result = false;
-	return result;
+	return gogcu->application->GetData (gogcu, data, length, clearfunc, user_data);
 }
 
 static void
 go_gchemutils_component_set_data (GOComponent *component)
 {
 	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (component);
+	if (!gogcu->application) {
+		gogcu->application = Apps[component->mime_type];
+		if (!gogcu->application)
+			return;
+	}
+	gogcu->document = gogcu->application->ImportDocument (component->mime_type, component->data, component->length);
+	gogcu->application->UpdateBounds (gogcu);
 }
 	
 static void
 go_gchemutils_component_render (GOComponent *component, cairo_t *cr,
 						  double width, double height)
 {
-	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (component);		  
+	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (component);
+	gogcu->application->Render (gogcu, cr, width, height);
 }
 
 static GtkWindow*
 go_gchemutils_component_edit (GOComponent *component)
 {
 	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (component);
-	return NULL;
+	if (!gogcu->document) {
+		component->ascent = 1.;
+		component->descent = 0.;
+		component->width = 1.;
+	}
+	if (gogcu->window) {
+		gogcu->window->Show ();
+		return gogcu->window->GetWindow ();
+	}
+	if (!gogcu->application) {
+		gogcu->application = Apps[component->mime_type];
+		if (!gogcu->application)
+			return NULL;
+	}
+	return gogcu->application->EditDocument (gogcu);
 }
 
 static void
 go_gchemutils_component_finalize (GObject *obj)
 {
 	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (obj);
+	if (gogcu->window)
+		gogcu->window->Destroy ();
 	G_OBJECT_CLASS (gogcu_parent_klass)->finalize (obj);
 }
 
@@ -82,7 +112,7 @@ static void
 go_gchemutils_component_init (GOComponent *component)
 {
 	component->resizable = false;
-	component->editable = false;	// set it to true for editable docs
+	component->editable = true;
 	component->window = NULL;
 	component->ascent = 1.;
 	component->descent = 0.;
@@ -118,15 +148,17 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 #endif
 	GTypeModule *module = go_plugin_get_type_module (plugin);
 	go_gchemutils_component_register_type (module);
-	go_components_set_mime_suffix ("chemical/x-xyz", "*.xyz");
+//	go_components_set_mime_suffix ("chemical/x-xyz", "*.xyz");
 	go_components_set_mime_suffix ("application/x-gchempaint", "*.gchempaint");
-	go_components_set_mime_suffix ("application/x-gcrystal", "*.gcrystal");
+	Apps["application/x-gchempaint"] = new GOGcpApplication ();
+//	go_components_set_mime_suffix ("application/x-gcrystal", "*.gcrystal");
 // TODO: add other types
 }
 
 G_MODULE_EXPORT void
 go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
+	// TODO: clean
 }
 
 }	// extern "C"
